% This routine implements the Newton-Raphson's method of rootfinding.
% The following are the input parameters to the routine :
%    f : it is any function involving one independent variable of the form f( variables ) = 0.
%           i.e. all the terms of the function have to be transferred to LHS making RHS as 0.
%    df : the derivative of f.
%    x0 : initial guess of the root / starting value.
%    N : maximum number of iterations needed to be performed.
%    tol : allowable deviation / tolerance.

function xcur = new_raph( f, df, x0, N, tol, a, b )

   k = 1;        % iteration counter
   x(1) = x0;    % some random initialisations
   xcur = x(1);
   
   f = inline(f); 
   df = inline(df); 
   
   fplot(f,[a b]);
   %ezplot(f,[a b]);
   grid on; hold on;
   fprintf('%3g %10.4f %10.4f\n',k, x(k), f(x(k)))

   while( k <= N )
      fx = f(x(k));
      dfx = df(x(k));

      if( dfx == 0 )
         error( 'Derivative has become 0' );
      else
         k = k + 1;
         x(k) = x(k-1) - fx / dfx;
         xcur = x(k);
         plot(x(k),f(x(k)),'ro');
         fprintf('%3g %10.4f %10.4f\n',k, x(k), f(x(k)))
      end
      
      if (abs(x(k-1)-x(k)) <= tol) 
          return;
      end

   end
   
return;

